package com.sygem.swing.demos;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.sygem.swing.renderers.*;

/**
 * <p>Title: Renderers</p>
 * <p>Description: A set of reusable component renderers</p>
 * <p>Copyright: Copyright (c) 2004</p>
 * <p>Company: SyGem Software</p>
 * @author Simon Jewell
 * @version 1.0
 */

public class RenderersDemoFrame extends JFrame {
  JPanel contentPane;
  GridBagLayout gridBagLayout1 = new GridBagLayout();
  JButton jButton1 = null;
  JLabel jLabel1 = null;
  JTextField jTextField1 = null;
  JTextArea jTextArea1 = null;
  JPanel jPanel1 = null;
  JLabel jLabel2 = new JLabel();

  //Construct the frame
  public RenderersDemoFrame() {
    enableEvents(AWTEvent.WINDOW_EVENT_MASK);
    try {
      jbInit();
    }
    catch(Exception e) {
      e.printStackTrace();
    }
  }

  //Component initialization
  private void jbInit() throws Exception  {
    contentPane = (JPanel) this.getContentPane();
    contentPane.setLayout(gridBagLayout1);
    this.setSize(new Dimension(500, 200));
    this.setTitle("Custom Component Renderers");

    jButton1 = new JButton() {
      GradientBackgroundRenderer renderer = new GradientBackgroundRenderer(Color.gray,Color.yellow);
      public void paintComponent(Graphics g) {
        super.paintComponent(g);
        ((Graphics2D)g).setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER,0.25f));
        renderer.renderBackground(this,(Graphics2D)g);
      }
    };
    jButton1.setText("Subtle button");

    jLabel1 = new JLabel() {
      GradientBackgroundRenderer renderer = new GradientBackgroundRenderer(Color.green,Color.magenta);
      public void paintComponent(Graphics g) {
        ((Graphics2D)g).setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER,0.25f));
        renderer.renderBackground(this,(Graphics2D)g);
        ((Graphics2D)g).setComposite(AlphaComposite.getInstance(AlphaComposite.SRC));
        super.paintComponent(g);
      }
    };
    jLabel1.setText("jLabel1");

    jTextField1 = new JTextField() {
      GradientBackgroundRenderer renderer = new GradientBackgroundRenderer(Color.gray,Color.red);
      public void paintComponent(Graphics g) {
        super.paintComponent(g);
        ((Graphics2D)g).setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER,0.25f));
        renderer.renderBackground(this,(Graphics2D)g);
      }
    };
    jTextField1.setText("jTextField1");

    jTextArea1 = new JTextArea() {
      GradientBackgroundRenderer renderer = new GradientBackgroundRenderer(Color.gray,Color.red);
      public void paintComponent(Graphics g) {
        super.paintComponent(g);
        ((Graphics2D)g).setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER,0.25f));
        renderer.renderBackground(this,(Graphics2D)g);
      }
    };
    jTextArea1.setText("jTextArea1");

    jLabel2.setText("Blue -> Yellow background on this custom JPanel");
    jPanel1 = new JPanel() {
      GradientBackgroundRenderer renderer = new GradientBackgroundRenderer(Color.blue,Color.yellow);
      public void paintComponent(Graphics g) {
        super.paintComponent(g);
        renderer.renderBackground(this,(Graphics2D)g);
      }
    };

    contentPane.add(jButton1,        new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
            ,GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(15, 15, 15, 15), 0, 0));
    contentPane.add(jPanel1,        new GridBagConstraints(0, 1, 4, 1, 1.0, 1.0
            ,GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
    jPanel1.add(jLabel2, null);
    contentPane.add(jLabel1,       new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0
            ,GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(0, 15, 0, 15), 0, 0));
    contentPane.add(jTextField1,    new GridBagConstraints(2, 0, 1, 1, 0.0, 0.0
            ,GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(0, 15, 0, 15), 0, 0));
    contentPane.add(jTextArea1,  new GridBagConstraints(3, 0, 1, 1, 0.0, 0.0
            ,GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(0, 15, 0, 15), 0, 0));
  }

  //Overridden so we can exit when window is closed
  protected void processWindowEvent(WindowEvent e) {
    super.processWindowEvent(e);
    if (e.getID() == WindowEvent.WINDOW_CLOSING) {
      System.exit(0);
    }
  }
}
